@@ -5,7 +5,9 @@ from __future__ import division
 __status__ = "Development"
 
 import unittest
-from doped.pycdt.utils.units import k_to_eV, eV_to_k
+
+from doped.pycdt.utils.units import eV_to_k, k_to_eV
+
 
 class EnergyFunctionsTest(unittest.TestCase):
     def test_k_to_eV(self):
@@ -13,9 +15,10 @@ class EnergyFunctionsTest(unittest.TestCase):
         self.assertAlmostEqual(k_to_eV(g), 0.5333804)
 
     def test_eV_to_k(self):
-        self.assertAlmostEqual(eV_to_k(1.), 0.9681404248678961)
+        self.assertAlmostEqual(eV_to_k(1.0), 0.9681404248678961)
 
 
 import unittest
-if __name__ == '__main__':
+
+if __name__ == "__main__":
     unittest.main()
